@@ -1,14 +1,11 @@
 /*
  * Configuration file for CUPS on Windows.
  *
- * Copyright © 2007-2018 by Apple Inc.
+ * Copyright © 2007-2019 by Apple Inc.
  * Copyright © 1997-2007 by Easy Software Products.
  *
- * These coded instructions, statements, and computer programs are the
- * property of Apple Inc. and are protected by Federal copyright
- * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
- * which should have been included with this file.  If this file is
- * missing or damaged, see the license at "http://www.cups.org/".
+ * Licensed under Apache License v2.0.  See the file "LICENSE" for more
+ * information.
  */
 
 #ifndef _CUPS_CONFIG_H_
@@ -44,16 +41,22 @@
 #define open		_open
 #define read	        _read
 #define rmdir		_rmdir
-#define snprintf 	_snprintf
 #define strdup		_strdup
 #define unlink		_unlink
-#define vsnprintf 	_vsnprintf
 #define write		_write
 
 
 /*
- * Map the POSIX strcasecmp() and strncasecmp() functions to the Win32 stricmp()
- * and strnicmp() functions...
+ * Microsoft "safe" functions use a different argument order than POSIX...
+ */
+
+#define gmtime_r(t,tm)	gmtime_s(tm,t)
+#define localtime_r(t,tm) localtime_s(tm,t)
+
+
+/*
+ * Map the POSIX strcasecmp() and strncasecmp() functions to the Win32
+ * _stricmp() and _strnicmp() functions...
  */
 
 #define strcasecmp	_stricmp
@@ -94,8 +97,8 @@ typedef unsigned long useconds_t;
  * Version of software...
  */
 
-#define CUPS_SVERSION "CUPS v2.2.8"
-#define CUPS_MINIMAL "CUPS/2.2.8"
+#define CUPS_SVERSION "CUPS v2.3.3"
+#define CUPS_MINIMAL "CUPS/2.3.3"
 
 
 /*
@@ -327,8 +330,9 @@ typedef unsigned long useconds_t;
  * Do we have the (v)snprintf() functions?
  */
 
-#define HAVE_SNPRINTF 1
-#define HAVE_VSNPRINTF 1
+/* Windows snprintf/vsnprintf are non-conforming */
+/* #undef HAVE_SNPRINTF */
+/* #undef HAVE_VSNPRINTF */
 
 
 /*
@@ -398,21 +402,9 @@ typedef unsigned long useconds_t;
  */
 
 /* #undef HAVE_AUTHORIZATION_H */
-/* #undef HAVE_SECBASEPRIV_H */
 /* #undef HAVE_SECCERTIFICATE_H */
-/* #undef HAVE_SECIDENTITYSEARCHPRIV_H */
 /* #undef HAVE_SECITEM_H */
-/* #undef HAVE_SECITEMPRIV_H */
 /* #undef HAVE_SECPOLICY_H */
-/* #undef HAVE_SECPOLICYPRIV_H */
-/* #undef HAVE_SECURETRANSPORTPRIV_H */
-
-
-/*
- * Do we have the cssmErrorString function?
- */
-
-/* #undef HAVE_CSSMERRORSTRING */
 
 
 /*
@@ -422,20 +414,6 @@ typedef unsigned long useconds_t;
 /* #undef HAVE_SECGENERATESELFSIGNEDCERTIFICATE */
 
 
-/*
- * Do we have the SecKeychainOpen function?
- */
-
-/* #undef HAVE_SECKEYCHAINOPEN */
-
-
-/*
- * Do we have (a working) SSLSetEnabledCiphers function?
- */
-
-#define HAVE_SSLSETENABLEDCIPHERS 1
-
-
 /*
  * Do we have libpaper?
  */
@@ -578,26 +556,10 @@ typedef unsigned long useconds_t;
 
 
 /*
- * Various scripting languages...
- */
-
-/* #undef HAVE_JAVA */
-#define CUPS_JAVA	""
-/* #undef HAVE_PERL */
-#define CUPS_PERL	""
-/* #undef HAVE_PHP */
-#define CUPS_PHP	""
-/* #undef HAVE_PYTHON */
-#define CUPS_PYTHON	""
-
-
-/*
- * Do we have CoreFoundation public and private headers?
+ * Do we have CoreFoundation public headers?
  */
 
 /* #undef HAVE_COREFOUNDATION_H */
-/* #undef HAVE_CFPRIV_H */
-/* #undef HAVE_CFBUNDLEPRIV_H */
 
 
 /*
@@ -626,7 +588,6 @@ typedef unsigned long useconds_t;
  */
 
 /* #undef HAVE_MEMBERSHIP_H */
-/* #undef HAVE_MEMBERSHIPPRIV_H */
 /* #undef HAVE_MBR_UID_TO_UUID */
 
 
@@ -779,14 +740,6 @@ typedef unsigned long useconds_t;
  */
 
 /* #undef HAVE_XPC */
-/* #undef HAVE_XPC_PRIVATE_H */
-
-
-/*
- * Do we have Mini-XML?
- */
-
-/* #undef HAVE_MXML_H */
 
 
 /*
